@@ -1,21 +1,20 @@
-from typing import Optional
-from agentifyme.document_stores.vector.base import VectorDocumentStore
+
 from qdrant_client import QdrantClient
 
+from agentifyme.document_stores.vector.base import VectorDocumentStore
+
 
 class QdrantVectorDocumentStore(VectorDocumentStore):
-
     def __init__(
         self,
-        location: Optional[str] = None,
-        url: Optional[str] = None,
-        port: Optional[int] = 6333,
+        location: str | None = None,
+        url: str | None = None,
+        port: int | None = 6333,
         grpc_port: int = 6334,
         prefer_grpc: bool = False,
-        api_key: Optional[str] = None,
-        path: Optional[str] = None,
+        api_key: str | None = None,
+        path: str | None = None,
     ):
-
         self.client = QdrantClient(
             location=location,
             url=url,
